@@ -6,7 +6,7 @@ var searchData=
   ['basic_20logging_20functionality_3',['Basic logging functionality.',['../a02540.html',1,'']]],
   ['bcomplete_4',['bComplete',['../a00898.html#a5554ca9c80e573aba7b98aaab7630025',1,'_typelib_TypeDescription']]],
   ['bdisposed_5',['bDisposed',['../a01874.html#a929dd79785e30217bc7d53152c1b455a',1,'cppu::OBroadcastHelperVar']]],
-  ['begin_6',['begin',['../a01010.html#a5c3e3426d06e79116df6fe56b14095b5',1,'com::sun::star::uno::Sequence::begin()'],['../a01010.html#abe93b8603cfb316737b269bc76475187',1,'com::sun::star::uno::Sequence::begin() const'],['../a01010.html#a5c3e3426d06e79116df6fe56b14095b5',1,'com::sun::star::uno::Sequence&lt; bool &gt;::begin()'],['../a01010.html#abe93b8603cfb316737b269bc76475187',1,'com::sun::star::uno::Sequence&lt; bool &gt;::begin() const']]],
+  ['begin_6',['begin',['../a01010.html#a5c3e3426d06e79116df6fe56b14095b5',1,'com::sun::star::uno::Sequence::begin()'],['../a01010.html#abe93b8603cfb316737b269bc76475187',1,'com::sun::star::uno::Sequence::begin() const'],['../a01010.html#a5c3e3426d06e79116df6fe56b14095b5',1,'com::sun::star::uno::Sequence&lt; bool &gt;::begin()']]],
   ['bin_7',['bIn',['../a00918.html#aa87139c0f6c1cc171cb401ff91a6198a',1,'_typelib_MethodParameter::bIn'],['../a00946.html#a4e3c822420f62a1ae07d401247ed4e2c',1,'_typelib_Parameter_Init::bIn']]],
   ['bind_8',['bind',['../a00858.html#a80d4fbebc159b4e4c2b8b60d3f5ff06e',1,'osl::Socket']]],
   ['bindispose_9',['bInDispose',['../a01874.html#a57c18e5807a8402f77d4769b1bc611d3',1,'cppu::OBroadcastHelperVar']]],
